function rho = baker_jayaram_correlation(T1, T2)
% [rho] = baker_jayaram_correlation(T1, T2)
%
% Compute the correlation of epsilon at two different periods for shallow
% crustal earthquakes in the PEER NGA database
%
% Author: Jack Baker
% Last Revised: June 25, 2007
% Reference: Baker, J.W. and Jayaram, N. (2008), "Correlation of spectral 
%   acceleration values from NGA ground motion models," Earthquake 
%   Spectra, 24 (1), 299-317. 
%
% INPUT
% T1, T2    = the two periods of interest. The periods may be equal, and 
%             there is no restriction on which is larger.
%
% OUTPUT
% rho       = predicted correlation coefficient
%
%--------------------------------------------------------------------------
%
% Provided as e-supplement to:
% Burks, L.S. and J.W. Baker (2013), "Validation of ground motion 
%   simulations through simple proxies for the response of engineered 
%   systems," Bulletin of the Seismological Society of America.
%
%--------------------------------------------------------------------------
 
T_min = min(T1, T2);
T_max = max(T1, T2);

C1 = (1-cos(pi/2 - log(T_max/max(T_min, 0.109)) * 0.366 ));
if T_max < 0.2
    C2 = 1 - 0.105*(1 - 1./(1+exp(100*T_max-5)))*(T_max-T_min)/(T_max-0.0099);
end
if T_max < 0.109
    C3 = C2;
else
    C3 = C1;
end
C4 = C1 + 0.5 * (sqrt(C3) - C3) * (1 + cos(pi*(T_min)/(0.109)));

if T_max <= 0.109
    rho = C2;
elseif T_min > 0.109
    rho = C1;
elseif T_max < 0.2
    rho = min(C2, C4);
else
    rho = C4;
end

        