function mu_ratio = fn_RotD100RotD50_ratio(T_star, method)
% mu_ratio = fn_RotD100_RotD50_ratio(T_star)
%
% Compute the mean of RotD100/RotD50 using the model by 
%   Shahi & Baker (2013) or Beyer & Bommer (2006)
%
% Author: Lynne Burks
% Last Revised: October 8, 2012
% References: (1) Shahi, S. K. and J. W. Baker (2013). NGA-West2 models 
%   for ground-motion directionality. Tech- nical Report PEER 2013/10, 
%   Pacific Earthquake Engineering Research Center, Berkeley, CA.
%   (2) Beyer, K. and J. J. Bommer (2006). "
%   Relationships between median values and between aleatory variabilities 
%   for different definitions of the horizontal component of motion," 
%   Bulletin of the Seis- mological Society of America, 96(4A), 1512?1522.
%
% INPUT
% T_star    = period of interest, must be between 0.01s and 10s, can be 
%             vector or scalar
% method    = 'SB2013' for Shahi & Baker (2013)
%           = 'BB2006' for Beyer & Bommer (2006)
%
% OUTPUT
% mu_ratio  = geometric mean of the ratio RotD100/RotD50
%
%--------------------------------------------------------------------------
%
% Provided as e-supplement to:
% Burks, L.S. and J.W. Baker (2013), "Validation of ground motion 
%   simulations through simple proxies for the response of engineered 
%   systems," Bulletin of the Seismological Society of America.
%
%--------------------------------------------------------------------------

if strcmp(method, 'SB2013')
    T = [0.01 0.02 0.03 0.05 0.075 0.1 0.15 0.2 0.25 0.3 0.4 0.5 0.75 1 1.5 2 3 4 5 7.5 10];
    ratio = [1.19 .* ones(1, 6) 1.2 .* ones(1, 2) 1.21 1.22 1.23 1.23 1.24 .* ones(1, 4), 1.25 1.25 1.26 1.28 1.29];
    mu_ratio = interp1(T, ratio, T_star);
    
elseif strcmp(method, 'BB2006')
    % correction from RotD50 to GMRotI50
    correction = [1.001, 1.001, 1.001, 1.002, 1.002, 1.002, 1.005, 1.01, 1.012, 1.015, 1.017, 1.02, 1.02, 1.023, 1.025, 1.027, 1.03, 1.035, 1.04, 1.05, 1.055];
    period = [0.01, 0.02, 0.03, 0.05, 0.075, 0.1, 0.15, 0.2, 0.25, 0.3, 0.4, 0.5, 0.75, 1, 1.5, 2, 3, 4, 5, 7.5, 10];

    % define Beyer & Bommer (2006) ratio (RotD100 / GMRotI50)
    period_other = [0.01, 0.05, 0.1, 0.15, 0.2, 0.3, 0.5, 0.8, 1, 2, 3, 4, 5, 10];
    ratio_other = [1.2, 1.2, 1.2, 1.2, 1.22, 1.24, 1.27, 1.3, 1.3, 1.3, 1.3, 1.3, 1.3, nan]; % Beyer and Bommer (2006) (Sa_RotD100/Sa_GM)

    % interpolate ratio to period for correction factor
    ratio2 = interp1(period_other, ratio_other, period);
    ratio2 = ratio2 ./ correction;

    % interpolate ratio to given periods
    mu_ratio = interp1(period, ratio2, T_star);
    
else
    error(['invalid method: ' method]);
end

    


